font-v
========

A font version reporting and modification tool.  font-v reports and modifies the OpenType name table nameID 5 records in ttf and otf fonts.

Source and documentation: https://github.com/source-foundry/font-v

Issue reporting: https://github.com/source-foundry/font-v/issues

License: MIT
